TTVideoABRStartupConfig class

Startup resolution selection configuration class Used to configure behavior parameters for startup resolution selection algorithm

Properties

defaultResolution TTVideoEngineResolutionType
Default resolution (usually used for the first video after app cold start)
getter/setter pair
displayHeight int?
Video display height (algorithm will reference this size to select the most appropriate resolution)
getter/setter pair
displayWidth int?
Video display width (algorithm will reference this size to select the most appropriate resolution)
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
Use Dart instance's hashCode as unique identifier
no setter
listener TTVideoABRStartupResolutionListener?
Callback listener after startup resolution selection is completed
getter/setter pair
mobileMaxResolution TTVideoEngineResolutionType
Maximum resolution under mobile network
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenHeight int?
Device screen height
getter/setter pair
screenWidth int?
Device screen width
getter/setter pair
userSelectedResolution TTVideoEngineResolutionType?
User's last manually selected resolution. If not null, this resolution will be prioritized
getter/setter pair
wifiMaxResolution TTVideoEngineResolutionType
Maximum resolution under Wi-Fi network
getter/setter pair

Methods

dispose() Future<void>
Dispose configuration
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setListener(TTVideoABRStartupResolutionListener listener) → void
Set listener
toMap() Map<String, dynamic>
Convert to Map for transmission to native side
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({int? screenWidth, int? screenHeight, TTVideoEngineResolutionType defaultResolution = TTVideoEngineResolutionType.TTVideoEngineResolutionTypeHD, TTVideoEngineResolutionType wifiMaxResolution = TTVideoEngineResolutionType.TTVideoEngineResolutionType1080P, TTVideoEngineResolutionType mobileMaxResolution = TTVideoEngineResolutionType.TTVideoEngineResolutionTypeFullHD, TTVideoEngineResolutionType? userSelectedResolution, int? displayWidth, int? displayHeight, TTVideoABRStartupResolutionListener? listener}) Future<TTVideoABRStartupConfig>
Async factory method to create configuration