TTVideoABRStrategy class
Startup resolution selection strategy class Provides startup resolution selection functionality, intelligently selecting appropriate resolution based on network conditions, device information, and business scenarios
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- isInitialized → bool
-
Get current ABR strategy initialization status
no setter
Static Methods
-
createConfigInternalByConfig(
{required TTVideoABRStartupConfig config}) → Future< void> - Internal method: Create startup resolution selection configuration (identified by config.hashCode)
-
dispose(
) → Future< void> - Dispose resources
-
init(
) → Future< void> - Initialize ABR global configuration Must be called in Application, required for startup resolution selection
-
initEngine(
{required dynamic player, required TTVideoABRStartupConfig config}) → Future< void> - Enable startup resolution selection for player instance
-
preloadSelect(
{required IVideoModel videoModel, required TTVideoABRStartupConfig config}) → Future< TTVideoEngineResolutionType?> - Get recommended resolution
-
removeConfigByHash(
int configHash) → Future< void> - Remove specified configuration (internal use)